==> apigateway-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/DomainName.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:22:40.449Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.DomainName")
public class DomainName extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.apigateway.IDomainName {

    protected DomainName(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DomainName(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DomainName(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.DomainNameProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * Imports an existing domain name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.apigateway.IDomainName fromDomainNameAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.DomainNameAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.apigateway.DomainName.class, "fromDomainNameAttributes", software.amazon.awscdk.services.apigateway.IDomainName.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     * Maps this domain to an API endpoint.
     * 
     * @param targetApi That target API endpoint, requests will be mapped to the deployment stage.
     * @param options Options for mapping to base path with or without a stage.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.apigateway.BasePathMapping addBasePathMapping(final software.amazon.awscdk.services.apigateway.IRestApi targetApi, final software.amazon.awscdk.services.apigateway.BasePathMappingOptions options) {
        return this.jsiiCall("addBasePathMapping", software.amazon.awscdk.services.apigateway.BasePathMapping.class, new Object[] { java.util.Objects.requireNonNull(targetApi, "targetApi is required"), options });
    }

    /**
     * Maps this domain to an API endpoint.
     * 
     * @param targetApi That target API endpoint, requests will be mapped to the deployment stage.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.apigateway.BasePathMapping addBasePathMapping(final software.amazon.awscdk.services.apigateway.IRestApi targetApi) {
        return this.jsiiCall("addBasePathMapping", software.amazon.awscdk.services.apigateway.BasePathMapping.class, new Object[] { java.util.Objects.requireNonNull(targetApi, "targetApi is required") });
    }

    /**
     * The domain name (e.g. `example.com`).
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDomainName() {
        return this.jsiiGet("domainName", java.lang.String.class);
    }

    /**
     * The Route53 alias target to use in order to connect a record set to this domain through an alias.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDomainNameAliasDomainName() {
        return this.jsiiGet("domainNameAliasDomainName", java.lang.String.class);
    }

    /**
     * The Route53 hosted zone ID to use in order to connect a record set to this domain through an alias.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDomainNameAliasHostedZoneId() {
        return this.jsiiGet("domainNameAliasHostedZoneId", java.lang.String.class);
    }
}

==> apigateway-1.10.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/DomainName.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-30T08:39:26.115Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.DomainName")
public class DomainName extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.apigateway.IDomainName {

    protected DomainName(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DomainName(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DomainName(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.DomainNameProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * Imports an existing domain name.
     * 
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param attrs This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.apigateway.IDomainName fromDomainNameAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.DomainNameAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.apigateway.DomainName.class, "fromDomainNameAttributes", software.amazon.awscdk.services.apigateway.IDomainName.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     * Maps this domain to an API endpoint.
     * 
     * @param targetApi That target API endpoint, requests will be mapped to the deployment stage. This parameter is required.
     * @param options Options for mapping to base path with or without a stage.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.apigateway.BasePathMapping addBasePathMapping(final software.amazon.awscdk.services.apigateway.IRestApi targetApi, final software.amazon.awscdk.services.apigateway.BasePathMappingOptions options) {
        return this.jsiiCall("addBasePathMapping", software.amazon.awscdk.services.apigateway.BasePathMapping.class, new Object[] { java.util.Objects.requireNonNull(targetApi, "targetApi is required"), options });
    }

    /**
     * Maps this domain to an API endpoint.
     * 
     * @param targetApi That target API endpoint, requests will be mapped to the deployment stage. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.apigateway.BasePathMapping addBasePathMapping(final software.amazon.awscdk.services.apigateway.IRestApi targetApi) {
        return this.jsiiCall("addBasePathMapping", software.amazon.awscdk.services.apigateway.BasePathMapping.class, new Object[] { java.util.Objects.requireNonNull(targetApi, "targetApi is required") });
    }

    /**
     * The domain name (e.g. `example.com`).
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDomainName() {
        return this.jsiiGet("domainName", java.lang.String.class);
    }

    /**
     * The Route53 alias target to use in order to connect a record set to this domain through an alias.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDomainNameAliasDomainName() {
        return this.jsiiGet("domainNameAliasDomainName", java.lang.String.class);
    }

    /**
     * The Route53 hosted zone ID to use in order to connect a record set to this domain through an alias.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDomainNameAliasHostedZoneId() {
        return this.jsiiGet("domainNameAliasHostedZoneId", java.lang.String.class);
    }
}
